function x = load24( filename, samples, offset )
%LOAD24
%
%	Function to load data from a file containing a stream
%		of short integers
%
%	x = load24( filename )
%
%	filename - a string containing the name of the input file
%	x	 - returned as a row matrix
%
%
%OPTIONAL ARGUMENTS...
%
%	x = load24( filename, samples )
%	x = load24( filename, samples, offset )
%
%	samples	 - then number of samples to load
%	offset	 - offset (in samples) of the first sample to be loaded
%
fid = fopen(filename);

if (nargin==1)
	x = fread( fid, inf, 'short' );
end

if (nargin==2)
	[x, count] = fread( fid, samples, 'short' );
	if (count~=samples)
		fprintf(1,'WARNING: only %d of %d samples read from %s\n', count, samples, filename );
	end
end

if (nargin>2)
	fprintf(1,'ERROR: offset not supported yet in load24()\n');
	x = 0;
end

fclose( fid );
